@@ -27,7 +27,8 @@ logger = logging.getLogger(__name__)
 __all__ = ['preprocessing_training']
 
 
-def preprocessing_training_common(df, config, model_type: str, mapping_dicts=None, imp=None):
+def preprocessing_training_common(df, config, industry_dictionary, state_dictionary,
+                                  mx_prob_dictionary, mx_bv_dictionary, model_type,imp=None):
     """Common functions used for every campaign in the processing
 
     Args:
@@ -57,39 +58,48 @@ def preprocessing_training_common(df, config, model_type: str, mapping_dicts=Non
     df = devutils.clean_rows_with_na(df=df, cols_to_clean_na=cols_to_clean_na)
 
     # creation of the dictionaries
-    if mapping_dicts is None:
-        logger.info("No mapping dicts present, creating them")
-        mapping_dicts = {}
-        mx_prob_dictionary, mx_bv_dictionary = devutils.create_class_dictionaries(df, "MXType")
-        df = devutils.map_conv_prob_using_dictionary(df, mx_prob_dictionary, mx_bv_dictionary, 'MXType')
-        mapping_dicts['mx_prob'] = mx_prob_dictionary
-        mapping_dicts['mx_bv'] = mx_bv_dictionary
-        state_prob_dictionary, state_bv_dictionary = devutils.create_class_dictionaries(df, "State")
-        df = devutils.map_conv_prob_using_dictionary(df, state_prob_dictionary, state_bv_dictionary, 'State')
-        mapping_dicts['state_prob'] = state_prob_dictionary
-        mapping_dicts['state_bv'] = state_bv_dictionary
-        industry_prob_dictionary, industry_bv_dictionary = devutils.create_class_dictionaries(df, "Industry")
-        df = devutils.map_conv_prob_using_dictionary(df, industry_prob_dictionary, industry_bv_dictionary, 'Industry')
-        mapping_dicts['industry_prob'] = industry_prob_dictionary
-        mapping_dicts['industry_bv'] = industry_bv_dictionary
+    # if mapping_dicts is None:
+    #     logger.info("No mapping dicts present, creating them")
+    #     mapping_dicts = {}
+    #     mx_prob_dictionary, mx_bv_dictionary = devutils.create_class_dictionaries(df, "MXType")
+    #     df = devutils.map_conv_prob_using_dictionary(df, mx_prob_dictionary, mx_bv_dictionary, 'MXType')
+    #     mapping_dicts['mx_prob'] = mx_prob_dictionary
+    #     mapping_dicts['mx_bv'] = mx_bv_dictionary
+    #     state_prob_dictionary, state_bv_dictionary = devutils.create_class_dictionaries(df, "State")
+    #     df = devutils.map_conv_prob_using_dictionary(df, state_prob_dictionary, state_bv_dictionary, 'State')
+    #     mapping_dicts['state_prob'] = state_prob_dictionary
+    #     mapping_dicts['state_bv'] = state_bv_dictionary
+    #     industry_prob_dictionary, industry_bv_dictionary = devutils.create_class_dictionaries(df, "Industry")
+    #     df = devutils.map_conv_prob_using_dictionary(df, industry_prob_dictionary, industry_bv_dictionary, 'Industry')
+    #     mapping_dicts['industry_prob'] = industry_prob_dictionary
+    #     mapping_dicts['industry_bv'] = industry_bv_dictionary
+    #
+    #     logging.info(mapping_dicts['industry_prob'])
+    #     logging.info(mapping_dicts['industry_bv'])
+    #     logging.info(mapping_dicts['mx_prob'])
+    #     logging.info(mapping_dicts['mx_bv'])
+    #     logging.info(mapping_dicts['state_prob'])
+    #     logging.info(mapping_dicts['state_bv'])
+    #
+    #     mapping_dicts_name = config['mapping_dicts_name']
+    #     mapping_dicts_output_path = os.path.join('/opt/ml/processing/mapping_dicts', mapping_dicts_name)
+    #     logging.info('Saving dicts to {}'.format(mapping_dicts_output_path))
+    #     pickle.dump(mapping_dicts, open(mapping_dicts_output_path, 'wb'))
+    # else:
+    #     logging.info("Mapping dicts found! Using them")
+    #     df = devutils.map_conv_prob_using_dictionary(df, mapping_dicts['mx_prob'], mapping_dicts['mx_bv'], 'MXType')
+    #     df = devutils.map_conv_prob_using_dictionary(df, mapping_dicts['state_prob'], mapping_dicts['state_bv'],
+    #                                                  'State')
+    #     df = devutils.map_conv_prob_using_dictionary(df, mapping_dicts['mx_prob'], mapping_dicts['mx_bv'], 'Industry')
 
-        logging.info(mapping_dicts['industry_prob'])
-        logging.info(mapping_dicts['industry_bv'])
-        logging.info(mapping_dicts['mx_prob'])
-        logging.info(mapping_dicts['mx_bv'])
-        logging.info(mapping_dicts['state_prob'])
-        logging.info(mapping_dicts['state_bv'])
+    df['Industry'] = df['Industry'].map(industry_dictionary)
+    logging.info( df['Industry'].value_counts() )
 
-        mapping_dicts_name = config['mapping_dicts_name']
-        mapping_dicts_output_path = os.path.join('/opt/ml/processing/mapping_dicts', mapping_dicts_name)
-        logging.info('Saving dicts to {}'.format(mapping_dicts_output_path))
-        pickle.dump(mapping_dicts, open(mapping_dicts_output_path, 'wb'))
-    else:
-        logging.info("Mapping dicts found! Using them")
-        df = devutils.map_conv_prob_using_dictionary(df, mapping_dicts['mx_prob'], mapping_dicts['mx_bv'], 'MXType')
-        df = devutils.map_conv_prob_using_dictionary(df, mapping_dicts['state_prob'], mapping_dicts['state_bv'],
-                                                     'State')
-        df = devutils.map_conv_prob_using_dictionary(df, mapping_dicts['mx_prob'], mapping_dicts['mx_bv'], 'Industry')
+    df['State'] = df['State'].map( state_dictionary )
+    logging.info( df['State'].value_counts() )
+
+    df = devutils.clean_mxtype_using_dictionary( df=df, mx_bv_dict=mx_bv_dictionary,
+                                                 mx_prob_dict=mx_prob_dictionary )
 
     # Normalize Type values
     df = devutils.clean_companytype(df)
@@ -149,11 +159,12 @@ def preprocessing_training_common(df, config, model_type: str, mapping_dicts=Non
     df.drop(labels=['idCampaign'], axis=1, inplace=True)
     df.insert(loc=0, value=status_col, column='idCampaign')
 
-    return df, imp, mapping_dicts
+    return df, imp
 
 
-def preprocessing_training(df, config, model_type,
-                           use_one_hot_encoding, mapping_dicts=None, imp=None):
+def preprocessing_training(df, industry_dictionary, state_dictionary,
+                           mx_bv_dictionary, mx_prob_dictionary, config, model_type,
+                           use_one_hot_encoding,imp=None):
     """[Pre-processing function to prepare the data for training the model and to make predictions]
 
     Args:
@@ -166,6 +177,7 @@ def preprocessing_training(df, config, model_type,
         model_type(string) : can be probability, bv or multiclass
     Returns:
         df_clean[Pandas Dataframe]: Pre-processed DataFrame ready for training purposes
+        :param mx_prob_dictionary:
         :param use_one_hot_encoding:
         :param mapping_dicts:
     """
@@ -180,7 +192,10 @@ def preprocessing_training(df, config, model_type,
     # Convert to categories and 
     df_leads_clean, imp, mapping_dicts = preprocessing_training_common(df=df_leads_clean,
                                                                        config=config,
-                                                                       mapping_dicts=mapping_dicts,
+                                                                       industry_dictionary=industry_dictionary,
+                                                                       mx_prob_dictionary=mx_prob_dictionary,
+                                                                       mx_bv_dictionary=mx_bv_dictionary,
+                                                                       state_dictionary=state_dictionary,
                                                                        model_type=model_type,
                                                                        imp=imp)
 
@@ -198,4 +213,4 @@ def preprocessing_training(df, config, model_type,
     logging.info("NA in final dataframe:")
     logging.info(f"{nna}")
 
-    return df_leads_clean, imp, mapping_dicts
+    return df_leads_clean, imp
